@@ -51,15 +51,12 @@ vpn_plugin_changed_cb (NMVpnEditorPlugin *plugin, CEPageVpn *self)
 }
 
 static void
-finish_setup (CEPageVpn *self, gpointer unused, GError *error, gpointer user_data)
+finish_setup (CEPageVpn *self, gpointer user_data)
 {
 	CEPage *parent = CE_PAGE (self);
 	CEPageVpnPrivate *priv = CE_PAGE_VPN_GET_PRIVATE (self);
 	GError *local = NULL;
 
-	if (error)
-		return;
-
 	g_return_if_fail (NM_IS_VPN_EDITOR_PLUGIN (priv->plugin));
 
 	priv->editor = nm_vpn_editor_plugin_get_editor (priv->plugin, CE_PAGE (self)->connection, &local);
@@ -78,7 +75,6 @@ finish_setup (CEPageVpn *self, gpointer unused, GError *error, gpointer user_dat
 		return;
 	}
 	g_object_ref_sink (parent->page);
-	gtk_widget_show_all (parent->page);
 }
 
 CEPage *
@@ -123,7 +119,7 @@ ce_page_vpn_new (NMConnectionEditor *editor,
 	}
 	priv->plugin = g_object_ref (priv->plugin);
 
-	g_signal_connect (self, "initialized", G_CALLBACK (finish_setup), NULL);
+	g_signal_connect (self, CE_PAGE_INITIALIZED, G_CALLBACK (finish_setup), NULL);
 
 	*out_secrets_setting_name = NM_SETTING_VPN_SETTING_NAME;
 
