@@ -28,17 +28,15 @@
 
 #include "mb-menu-item.h"
 
-G_DEFINE_TYPE (NMMbMenuItem, nm_mb_menu_item, GTK_TYPE_IMAGE_MENU_ITEM);
+G_DEFINE_TYPE (NMMbMenuItem, nm_mb_menu_item, GTK_TYPE_MENU_ITEM);
 
 #define NM_MB_MENU_ITEM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), NM_TYPE_MB_MENU_ITEM, NMMbMenuItemPrivate))
 
 typedef struct {
-#ifndef ENABLE_INDICATOR
 	GtkWidget *strength;
 	GtkWidget *detail;
 	GtkWidget *hbox;
 	GtkWidget *desc;
-#endif
 
 	char *desc_string;
 	guint32    int_strength;
@@ -80,9 +78,6 @@ update_label (NMMbMenuItem *item, gboolean use_bold)
 {
 	NMMbMenuItemPrivate *priv = NM_MB_MENU_ITEM_GET_PRIVATE (item);
 
-#ifdef ENABLE_INDICATOR
-	gtk_menu_item_set_label (GTK_MENU_ITEM (item), priv->desc_string);
-#else
 	gtk_label_set_use_markup (GTK_LABEL (priv->desc), use_bold);
 	if (use_bold) {
 		char *markup = g_markup_printf_escaped ("<b>%s</b>", priv->desc_string);
@@ -91,7 +86,6 @@ update_label (NMMbMenuItem *item, gboolean use_bold)
 		g_free (markup);
 	} else
 		gtk_label_set_text (GTK_LABEL (priv->desc), priv->desc_string);
-#endif
 }
 
 GtkWidget *
@@ -186,21 +180,8 @@ nm_mb_menu_item_new (const char *connection_name,
 	/* And the strength icon, if we have strength information at all */
 	if (enabled && strength) {
 		const char *icon_name = mobile_helper_get_quality_icon_name (strength);
-		GdkPixbuf *pixbuf = nma_icon_check_and_load (icon_name, applet);
 
-#ifdef ENABLE_INDICATOR
-#ifdef DBUSMENU_PIXMAP_SUPPORT
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_pixbuf (pixbuf));
-#else
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item),
-		                               gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU));
-		pixbuf = NULL;
-#endif
-		/* For some reason we must always re-set always-show after setting the image */
-		gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (item), TRUE);
-#else
-		gtk_image_set_from_pixbuf (GTK_IMAGE (priv->strength), pixbuf);
-#endif
+		gtk_image_set_from_pixbuf (GTK_IMAGE (priv->strength), nma_icon_check_and_load (icon_name, applet));
 	}
 
 	return GTK_WIDGET (item);
@@ -211,7 +192,6 @@ nm_mb_menu_item_new (const char *connection_name,
 static void
 nm_mb_menu_item_init (NMMbMenuItem *self)
 {
-#ifndef ENABLE_INDICATOR
 	NMMbMenuItemPrivate *priv = NM_MB_MENU_ITEM_GET_PRIVATE (self);
 
 	priv->hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
@@ -227,9 +207,6 @@ nm_mb_menu_item_init (NMMbMenuItem *self)
 	gtk_widget_show (priv->desc);
 	gtk_widget_show (priv->strength);
 	gtk_widget_show (priv->hbox);
-#else
-	gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (self), TRUE);
-#endif
 }
 
 static void
